@@ -40,10 +40,15 @@ function(i)
 function(x)
 {
     x <- as.character(x)
-    x[nchar(x) == 0L] <- "_"
-    x <- substr(x, start = 1, stop = 256)
-    while(any((n <- nchar(x, "byte")) > 256))
-        x <- substr(x, 1, 256 - ceiling(n / 2))
+    ind <- !is.na(x)
+    if (any(ind)) {
+        y <- x[ind]
+        y[!nzchar(y)] <- "_"
+        y <- substr(y, start = 1, stop = 256)
+        while(any((n <- nchar(y, "byte")) > 256))
+            y <- substr(y, 1, 256 - ceiling(n / 2))
+        x[ind] <- y
+    }
     x
 }
 
